'use strict';

exports.__esModule = true;
exports.sheet = undefined;
exports.flush = flush;
exports.css = css;
exports.fragment = fragment;
exports.keyframes = keyframes;
exports.fontFace = fontFace;
exports.hydrate = hydrate;

var _sheet = require('./sheet');

var _hash = require('./hash');

var _hash2 = _interopRequireDefault(_hash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var sheet = exports.sheet = new _sheet.StyleSheet();
sheet.inject();

var inserted = {};

function flush() {
  sheet.flush();
  inserted = {};
  sheet.inject();
}

function css(cls, vars, content) {
  // inline mode
  vars = vars.map(function (v) {
    return (/^frag-/.exec(v) ? fragments[v] : v
    );
  });
  var src = content.apply(undefined, vars);
  var hash = (0, _hash2.default)(src);

  if (!inserted[hash]) {
    inserted[hash] = true;
    src.map(function (r) {
      return r.replace(new RegExp(cls, 'gm'), cls + '-' + hash);
    }).forEach(function (r) {
      return sheet.insert(r);
    });
  }
  return cls + '-' + hash;
}

var fragments = {};

function fragment(frag, vars, content) {
  vars = vars.map(function (v) {
    return (/^frag-/.exec(v) ? fragments[v] : v
    );
  });
  var src = content.apply(undefined, vars);
  if (src.length > 1) {
    throw new Error('what up!');
  }

  var hash = (0, _hash2.default)(src);
  src = src.join('');
  fragments[frag + '-' + hash] = src.substring(src.indexOf('{') + 1, src.length - 1);
  return frag + '-' + hash;
}

function keyframes(kfm, vars, content) {
  var src = content.apply(undefined, vars);
  var hash = (0, _hash2.default)(src);
  if (!inserted[hash]) {
    inserted[hash] = true;
    src.forEach(function (r) {
      return sheet.insert('@keyframes ' + kfm + '-' + hash + ' {' + r + '}');
    });
  }
  return kfm + '-' + hash;
}

function fontFace(fontRules, vars, content) {
  var src = content.apply(undefined, vars);
  var hash = (0, _hash2.default)(src);
  if (!inserted[hash]) {
    inserted[hash] = true;
    src.forEach(function (r) {
      return sheet.insert(r);
    });
  }
  return fontRules + '-' + hash;
}

function hydrate(ids) {
  ids.forEach(function (id) {
    return inserted[id] = true;
  });
}